.. _config:

=============
Configuration
=============

.. toctree::
   :maxdepth: 2

   config-services-agent
   config-ml2
   config-address-scopes
   config-auto-allocation
   config-az
   config-bgp-dynamic-routing
   config-dhcp-ha
   config-dns-int
   config-dns-res
   config-dvr-ha-snat
   config-ipam
   config-ipv6
   config-lbaas
   config-macvtap
   config-mtu
   config-ovs-dpdk
   config-ovsfwdriver
   config-qos
   config-rbac
   config-routed-networks
   config-sfc
   config-sriov
   config-subnet-pools
   config-service-subnets
   config-trunking

.. note::

   For general configuration, see the `Configuration Reference
   <https://docs.openstack.org/ocata/config-reference/>`_.
